@@ -34,11 +34,15 @@ class Recipe(GenericSlapRecipe):
   """
   def _install(self):
     path_list = []
-    web_checker_mail_address = self.parameter_dict['web-checker-mail-address']
-    web_checker_smtp_host = self.parameter_dict['web-checker-smtp-host']
-    web_checker_frontend_url = self.parameter_dict.get(
-                                 'web-checker-frontend-url',
-                                 self.options['frontend-url'])
+    try:
+      web_checker_mail_address = self.options['mail-address']
+      web_checker_smtp_host = self.options['smtp-host']
+      web_checker_frontend_url = self.options['frontend-url']
+    except KeyError:
+      # BBB
+      web_checker_mail_address = self.parameter_dict['web-checker-mail-address']
+      web_checker_smtp_host = self.parameter_dict['web-checker-smtp-host']
+      web_checker_frontend_url = self.parameter_dict['web-checker-frontend-url']
     web_checker_working_directory = \
       self.options['web-checker-working-directory']
     config = dict(
